integration

package
v1.28.0-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 29, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AssertHTMLElement

func AssertHTMLElement[T int | bool](t testing.TB, doc *HTMLDoc, selector string, checkExists T)

AssertHTMLElement check if the element by selector exists or does not exist depending on checkExists

Types

type HTMLDoc

type HTMLDoc struct {
	// contains filtered or unexported fields
}

HTMLDoc struct

func NewHTMLParser

func NewHTMLParser(t testing.TB, body io.Reader) *HTMLDoc

NewHTMLParser parse html file

func (*HTMLDoc) Find

func (doc *HTMLDoc) Find(selector string) *goquery.Selection

Find gets the descendants of each element in the current set of matched elements, filtered by a selector. It returns a new Selection object containing these matched elements.

func (*HTMLDoc) GetInputValueByName

func (doc *HTMLDoc) GetInputValueByName(name string) string

GetInputValueByName for get input value by name

Jump to