Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type HTMLDoc ¶
type HTMLDoc struct {
// contains filtered or unexported fields
}
HTMLDoc struct
func NewHTMLParser ¶
NewHTMLParser parse html file
func (*HTMLDoc) Find ¶
Find gets the descendants of each element in the current set of matched elements, filtered by a selector. It returns a new Selection object containing these matched elements.
func (*HTMLDoc) GetInputValueByName ¶
GetInputValueByName for get input value by name
Click to show internal directories.
Click to hide internal directories.